@@ -4,7 +4,8 @@ use glob::glob;
 use std::path::Path;
 use std::{env, fs, u64};
 use tree_sitter_cli::{
-    generate, highlight, logger, parse, playground, query, tags, test, test_highlight, util, wasm,
+    generate, highlight, logger, parse, playground, query, tags, test, test_highlight, test_tags,
+    util, wasm,
 };
 use tree_sitter_config::Config;
 use tree_sitter_loader as loader;
@@ -338,6 +339,11 @@ fn run() -> Result<()> {
             if test_highlight_dir.is_dir() {
                 test_highlight::test_highlights(&loader, &test_highlight_dir)?;
             }
+
+            let test_tag_dir = test_dir.join("tags");
+            if test_tag_dir.is_dir() {
+                test_tags::test_tags(&loader, &test_tag_dir)?;
+            }
         }
 
         ("parse", Some(matches)) => {
